==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/AzurePlatformStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AzurePlatformStatusFluentImpl<A extends AzurePlatformStatusFluent<A>> extends BaseFluent<A> implements AzurePlatformStatusFluent<A>{
  public AzurePlatformStatusFluentImpl() {
  }
  public AzurePlatformStatusFluentImpl(AzurePlatformStatus instance) {
    this.withArmEndpoint(instance.getArmEndpoint()); 
    this.withCloudName(instance.getCloudName()); 
    this.withNetworkResourceGroupName(instance.getNetworkResourceGroupName()); 
    this.withResourceGroupName(instance.getResourceGroupName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String armEndpoint;
  private String cloudName;
  private String networkResourceGroupName;
  private String resourceGroupName;
  private Map<String,Object> additionalProperties;
  public String getArmEndpoint() {
    return this.armEndpoint;
  }
  public A withArmEndpoint(String armEndpoint) {
    this.armEndpoint=armEndpoint; return (A) this;
  }
  public Boolean hasArmEndpoint() {
    return this.armEndpoint != null;
  }
  public String getCloudName() {
    return this.cloudName;
  }
  public A withCloudName(String cloudName) {
    this.cloudName=cloudName; return (A) this;
  }
  public Boolean hasCloudName() {
    return this.cloudName != null;
  }
  public String getNetworkResourceGroupName() {
    return this.networkResourceGroupName;
  }
  public A withNetworkResourceGroupName(String networkResourceGroupName) {
    this.networkResourceGroupName=networkResourceGroupName; return (A) this;
  }
  public Boolean hasNetworkResourceGroupName() {
    return this.networkResourceGroupName != null;
  }
  public String getResourceGroupName() {
    return this.resourceGroupName;
  }
  public A withResourceGroupName(String resourceGroupName) {
    this.resourceGroupName=resourceGroupName; return (A) this;
  }
  public Boolean hasResourceGroupName() {
    return this.resourceGroupName != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AzurePlatformStatusFluentImpl that = (AzurePlatformStatusFluentImpl) o;
    if (armEndpoint != null ? !armEndpoint.equals(that.armEndpoint) :that.armEndpoint != null) return false;
    if (cloudName != null ? !cloudName.equals(that.cloudName) :that.cloudName != null) return false;
    if (networkResourceGroupName != null ? !networkResourceGroupName.equals(that.networkResourceGroupName) :that.networkResourceGroupName != null) return false;
    if (resourceGroupName != null ? !resourceGroupName.equals(that.resourceGroupName) :that.resourceGroupName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(armEndpoint,  cloudName,  networkResourceGroupName,  resourceGroupName,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (armEndpoint != null) { sb.append("armEndpoint:"); sb.append(armEndpoint + ","); }
    if (cloudName != null) { sb.append("cloudName:"); sb.append(cloudName + ","); }
    if (networkResourceGroupName != null) { sb.append("networkResourceGroupName:"); sb.append(networkResourceGroupName + ","); }
    if (resourceGroupName != null) { sb.append("resourceGroupName:"); sb.append(resourceGroupName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/AzurePlatformStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AzurePlatformStatusFluentImpl<A extends AzurePlatformStatusFluent<A>> extends BaseFluent<A> implements AzurePlatformStatusFluent<A>{
  public AzurePlatformStatusFluentImpl() {
  }
  public AzurePlatformStatusFluentImpl(AzurePlatformStatus instance) {
    if (instance != null) {
      this.withArmEndpoint(instance.getArmEndpoint());
      this.withCloudName(instance.getCloudName());
      this.withNetworkResourceGroupName(instance.getNetworkResourceGroupName());
      this.withResourceGroupName(instance.getResourceGroupName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String armEndpoint;
  private String cloudName;
  private String networkResourceGroupName;
  private String resourceGroupName;
  private Map<String,Object> additionalProperties;
  public String getArmEndpoint() {
    return this.armEndpoint;
  }
  public A withArmEndpoint(String armEndpoint) {
    this.armEndpoint=armEndpoint; return (A) this;
  }
  public Boolean hasArmEndpoint() {
    return this.armEndpoint != null;
  }
  public String getCloudName() {
    return this.cloudName;
  }
  public A withCloudName(String cloudName) {
    this.cloudName=cloudName; return (A) this;
  }
  public Boolean hasCloudName() {
    return this.cloudName != null;
  }
  public String getNetworkResourceGroupName() {
    return this.networkResourceGroupName;
  }
  public A withNetworkResourceGroupName(String networkResourceGroupName) {
    this.networkResourceGroupName=networkResourceGroupName; return (A) this;
  }
  public Boolean hasNetworkResourceGroupName() {
    return this.networkResourceGroupName != null;
  }
  public String getResourceGroupName() {
    return this.resourceGroupName;
  }
  public A withResourceGroupName(String resourceGroupName) {
    this.resourceGroupName=resourceGroupName; return (A) this;
  }
  public Boolean hasResourceGroupName() {
    return this.resourceGroupName != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AzurePlatformStatusFluentImpl that = (AzurePlatformStatusFluentImpl) o;
    if (!java.util.Objects.equals(armEndpoint, that.armEndpoint)) return false;

    if (!java.util.Objects.equals(cloudName, that.cloudName)) return false;

    if (!java.util.Objects.equals(networkResourceGroupName, that.networkResourceGroupName)) return false;

    if (!java.util.Objects.equals(resourceGroupName, that.resourceGroupName)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(armEndpoint,  cloudName,  networkResourceGroupName,  resourceGroupName,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (armEndpoint != null) { sb.append("armEndpoint:"); sb.append(armEndpoint + ","); }
    if (cloudName != null) { sb.append("cloudName:"); sb.append(cloudName + ","); }
    if (networkResourceGroupName != null) { sb.append("networkResourceGroupName:"); sb.append(networkResourceGroupName + ","); }
    if (resourceGroupName != null) { sb.append("resourceGroupName:"); sb.append(resourceGroupName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
